# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.data_plane_association import DataPlaneAssociation

class TestDataPlaneAssociation(unittest.TestCase):
    """DataPlaneAssociation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DataPlaneAssociation:
        """Test DataPlaneAssociation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DataPlaneAssociation`
        """
        model = DataPlaneAssociation()
        if include_optional:
            return DataPlaneAssociation(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                data_plane_id = '',
                project_id = '',
                data_plane = arthur_client.api_bindings.models.data_plane.DataPlane(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = '', 
                    name = '', 
                    workspace_id = '', 
                    description = '', 
                    user_id = '', 
                    infrastructure = 'AWS', 
                    last_check_in_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    capabilities = arthur_client.api_bindings.models.data_plane_capabilities.DataPlaneCapabilities(
                        gen_ai_enabled = True, ), ),
                project = arthur_client.api_bindings.models.project.Project(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = '', 
                    name = '', 
                    description = '', 
                    workspace_id = '', 
                    total_artifacts = 56, )
            )
        else:
            return DataPlaneAssociation(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                data_plane_id = '',
                project_id = '',
        )
        """

    def testDataPlaneAssociation(self):
        """Test DataPlaneAssociation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
