# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.resource_list_custom_aggregation_test_result import ResourceListCustomAggregationTestResult

class TestResourceListCustomAggregationTestResult(unittest.TestCase):
    """ResourceListCustomAggregationTestResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceListCustomAggregationTestResult:
        """Test ResourceListCustomAggregationTestResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceListCustomAggregationTestResult`
        """
        model = ResourceListCustomAggregationTestResult()
        if include_optional:
            return ResourceListCustomAggregationTestResult(
                records = [
                    arthur_client.api_bindings.models.custom_aggregation_test_result.CustomAggregationTestResult(
                        test_run_id = '', 
                        metric_name = '', 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        value = null, 
                        dimensions = [
                            arthur_client.api_bindings.models.dimension.Dimension(
                                name = '', 
                                value = '', )
                            ], )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, )
            )
        else:
            return ResourceListCustomAggregationTestResult(
                records = [
                    arthur_client.api_bindings.models.custom_aggregation_test_result.CustomAggregationTestResult(
                        test_run_id = '', 
                        metric_name = '', 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        value = null, 
                        dimensions = [
                            arthur_client.api_bindings.models.dimension.Dimension(
                                name = '', 
                                value = '', )
                            ], )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, ),
        )
        """

    def testResourceListCustomAggregationTestResult(self):
        """Test ResourceListCustomAggregationTestResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
